rule Dropper_DeploysMalwareViaSideLoading {
meta:
description = "Detect a dropper used to deploy an implant via side loading. This dropper has specifically been observed deploying REDLEAVES & PlugX"
author = "USG"
true_positive = "5262cb9791df50fafcb2fbd5f93226050b51efe400c2924eecba97b7ce437481: drops REDLEAVES. 6392e0701a77ea25354b1f40f5b867a35c0142abde785a66b83c9c8d2c14c0c3: drops plugx. "
reference = "https://www.us-cert.gov/ncas/alerts/TA17-117A"

strings:
$UniqueString = {2e 6c 6e 6b [0-14] 61 76 70 75 69 2e 65 78 65} // ".lnk" near "avpui.exe"
$PsuedoRandomStringGenerator = {b9 1a [0-6] f7 f9 46 80 c2 41 88 54 35 8b 83 fe 64} // Unique function that generates a 100 character pseudo random string.

condition:
any of them
}

rule REDLEAVES_DroppedFile_ImplantLoader_Starburn {
meta:
description = "Detect the DLL responsible for loading and deobfuscating the DAT file containing shellcode and core REDLEAVES RAT"
author = "USG"
true_positive = "7f8a867a8302fe58039a6db254d335ae" // StarBurn.dll
reference = "https://www.us-cert.gov/ncas/alerts/TA17-117A"
strings:
        $XOR_Loop = {32 0c 3a 83 c2 02 88 0e 83 fa 08 [4-14] 32 0c 3a 83 c2 02 88 0e 83 fa 10} // Deobfuscation loop
condition:
        any of them
}

rule REDLEAVES_DroppedFile_ObfuscatedShellcodeAndRAT_handkerchief {
meta:
description = "Detect obfuscated .dat file containing shellcode and core REDLEAVES RAT"
author = "USG"
true_positive = "fb0c714cd2ebdcc6f33817abe7813c36" // handkerchief.dat
reference = "https://www.us-cert.gov/ncas/alerts/TA17-117A"

strings:
    $RedleavesStringObfu = {73 64 65 5e 60 74 75 74 6c 6f 60 6d 5e 6d 64 60 77 64 72 5e 65 6d 6d 6c 60 68 6f 2f 65 6d 6d} // This is 'red_autumnal_leaves_dllmain.dll' XOR'd with 0x01
condition:
    any of them
}

rule REDLEAVES_CoreImplant_UniqueStrings {
meta:
description = "Strings identifying the core REDLEAVES RAT in its deobfuscated state"
author = "USG"
reference = "https://www.us-cert.gov/ncas/alerts/TA17-117A"

strings:
    $unique2 = "RedLeavesSCMDSimulatorMutex" nocase wide ascii
    $unique4 = "red_autumnal_leaves_dllmain.dll" wide ascii
    $unique7 = "\\NamePipe_MoreWindows" wide ascii
condition:
  any of them
}


